﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Samples.Data.Models.Series;
using Infragistics.Controls.Charts;
using System.Collections;
using System.Collections.ObjectModel;
using System.Collections.Specialized;

namespace XamDataChart_discontinuities
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            List<List<EnergyProduction>> seperatedData =
                GenerateSeperateDatasources(DataChart.Resources["energyProdData"] as EnergyProductionDataSample);

            BuildSeriesFromData(seperatedData);
        }

        public List<List<EnergyProduction>> GenerateSeperateDatasources(EnergyProductionDataSample data)
        {
            List<List<EnergyProduction>> seperatedData = new List<List<EnergyProduction>>();

            List<EnergyProduction> list = new List<EnergyProduction>();

            for (int i = 0; i < data.Count; i++)
            {

                if (data[i].Nuclear == null && data[i].Hydro == null)
                {
                    // Add the remaining data.
                    for (int j = i; j < data.Count; j++)
                    {
                        EnergyProduction energyData = new EnergyProduction();
                        energyData.Country = data[i].Country;
                        energyData.Hydro = null;
                        energyData.Nuclear = null;
                        list.Add(energyData);
                    }

                    int prevCount = seperatedData.Count;

                    seperatedData.Add(list);

                    list = new List<EnergyProduction>();

                    // Add the previous items but with no data.
                    for (int k = 0; k <= i; k++)
                    {
                        EnergyProduction energyData = new EnergyProduction();
                        energyData.Country = seperatedData[prevCount][k].Country;
                        energyData.Hydro = null;
                        energyData.Nuclear = null;
                        list.Add(energyData);
                    }
                }
                else
                {
                    EnergyProduction energyData = new EnergyProduction();
                    energyData.Country = data[i].Country;
                    energyData.Hydro = data[i].Hydro;
                    energyData.Nuclear = data[i].Nuclear;

                    list.Add(energyData);
                }
            }

            if (list.Count > 0)
                seperatedData.Add(list);

            return seperatedData;
        }

        public void BuildSeriesFromData(IEnumerable<IEnumerable<EnergyProduction>> seperatedData)
        {
            foreach (IEnumerable<EnergyProduction> data in seperatedData)
            {
                RangeAreaSeries ras = new RangeAreaSeries();
                ras.ItemsSource = data;
                ras.HighMemberPath = "Hydro";
                ras.LowMemberPath = "Nuclear";
                ras.Title = "Hydro vs Nuclear";
                ras.XAxis = DataChart.Axes[1] as CategoryXAxis;
                ras.YAxis = DataChart.Axes[0] as NumericYAxis;

                DataChart.Series.Add(ras);
            }
        }
    }
}
